summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source')
-rw-r--r--crawl-ref/source/spells4.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/crawl-ref/source/spells4.cc b/crawl-ref/source/spells4.cc
index d635cef39e..1563b48d54 100644
--- a/crawl-ref/source/spells4.cc
+++ b/crawl-ref/source/spells4.cc
@@ -2775,12 +2775,12 @@ void cast_divine_shield()
mpr("A divine shield forms around you!");
}
// duration of complete shield bonus up to 27 turns
you.duration[DUR_DIVINE_SHIELD]
- = 5 + (you.skills[SK_SHIELDS] + you.skills[SK_INVOCATIONS]*4)/6;
+ = 35 + (you.skills[SK_SHIELDS] + you.skills[SK_INVOCATIONS]*4)/3;
- // shield bonus up to 9
- you.attribute[ATTR_DIVINE_SHIELD] = 3 + you.skills[SK_SHIELDS]/4;
+ // shield bonus up to 8
+ you.attribute[ATTR_DIVINE_SHIELD] = 3 + you.skills[SK_SHIELDS]/5;
return;
}
@@ -2775,12 +2775,12 @@ void cast_divine_shield()
mpr("A divine shield forms around you!");
}
- // duration of complete shield bonus up to 27 turns
+ // duration of complete shield bonus from 35 to 80 turns
you.duration[DUR_DIVINE_SHIELD]